summaryrefslogtreecommitdiffstats
path: root/tools/repopick.py
diff options
context:
space:
mode:
Diffstat (limited to 'tools/repopick.py')
-rwxr-xr-xtools/repopick.py7
1 files changed, 4 insertions, 3 deletions
diff --git a/tools/repopick.py b/tools/repopick.py
index cfbb8a8..9bb39aa 100755
--- a/tools/repopick.py
+++ b/tools/repopick.py
@@ -1,6 +1,7 @@
#!/usr/bin/env python
#
# Copyright (C) 2013-15 The CyanogenMod Project
+# (C) 2017 The LineageOS Project
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
@@ -121,12 +122,12 @@ def fetch_query(remote_url, query):
raise Exception('Gerrit URL should be in the form http[s]://hostname/ or ssh://[user@]host[:port]')
if __name__ == '__main__':
- # Default to CyanogenMod Gerrit
- default_gerrit = 'http://review.cyanogenmod.org'
+ # Default to LineageOS Gerrit
+ default_gerrit = 'http://review.lineageos.org'
parser = argparse.ArgumentParser(formatter_class=argparse.RawDescriptionHelpFormatter, description=textwrap.dedent('''\
repopick.py is a utility to simplify the process of cherry picking
patches from CyanogenMod's Gerrit instance (or any gerrit instance of your choosing)
Given a list of change numbers, repopick will cd into the project path
and cherry pick the latest patch available.
@@ -121,12 +122,12 @@ def fetch_query(remote_url, query):
parser = argparse.ArgumentParser(formatter_class=argparse.RawDescriptionHelpFormatter, description=textwrap.dedent('''\
repopick.py is a utility to simplify the process of cherry picking
- patches from CyanogenMod's Gerrit instance (or any gerrit instance of your choosing)
+ patches from LineageOS's Gerrit instance (or any gerrit instance of your choosing)
Given a list of change numbers, repopick will cd into the project path
and cherry pick the latest patch available.